==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/workflowengine/l10n/de.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Saved" : "Gespeichert",
    "Saving failed:" : "Speichern fehlgeschlagen:",
    "File MIME type" : "Datei MIME-Typ",
    "is" : "ist",
    "is not" : "ist nicht",
    "matches" : "entspricht",
    "does not match" : "entspricht nicht",
    "Example: {placeholder}" : "Beispiel: {placeholder}",
    "File size (upload)" : "Dateigröße (beim Hochladen)",
    "less" : "weniger",
    "less or equals" : "weniger oder gleich",
    "greater or equals" : "größer oder gleich",
    "greater" : "größer",
    "File system tag" : "Dateisystem-Tag",
    "is tagged with" : "hat den Tag",
    "is not tagged with" : "hat nicht den Tag",
    "Select tag…" : "Wähle einen Tag…",
    "Request remote address" : "Entfernte Adresse anfordern",
    "matches IPv4" : "entspricht IPv4",
    "does not match IPv4" : "entspricht nicht IPv4",
    "matches IPv6" : "entspricht IPv6",
    "does not match IPv6" : "entspricht nicht IPv6",
    "Request time" : "Anfrage-Zeitpunkt",
    "between" : "zwischen",
    "not between" : "nicht zwischen",
    "Start" : "Start",
    "End" : "Ende",
    "Select timezone…" : "Wähle eine Zeitzone…",
    "Request URL" : "Anfrage-URL",
    "Predefined URLs" : "Vordefinierte URLs",
    "Files WebDAV" : "WebDAV für Dateien",
    "Request user agent" : "User-Agent",
    "Sync clients" : "Sync-Clients",
    "Android client" : "Android-Client",
    "iOS client" : "iOS-Client",
    "Desktop client" : "Desktop-Client",
    "User group membership" : "Benutzergruppen-Mitgliedschaft",
    "is member of" : "ist Mitglied von",
    "is not member of" : "ist kein Mitglied von",
    "The given operator is invalid" : "Der angegebene Operator ist ungültig",
    "The given regular expression is invalid" : "Der angegebene Reguläre Ausdruck ist ungültig",
    "The given file size is invalid" : "Die angegebene Dateigröße ist ungültig",
    "The given tag id is invalid" : "Die angegebene Tag ID ist ungültig",
    "The given IP range is invalid" : "Der angegebene IP-Bereich ist ungültig",
    "The given IP range is not valid for IPv4" : "Der angegebene IP-Bereich ist ungültig für IPv4",
    "The given IP range is not valid for IPv6" : "Der angegebene IP-Bereich ist ungültig für IPv6",
    "The given time span is invalid" : "Die angegebene Zeitspanne ist ungütlig",
    "The given start time is invalid" : "Die angegebene Anfangszeit ist ungültig",
    "The given end time is invalid" : "Die angegebene Endzeit ist ungültig",
    "The given group does not exist" : "Die angegebene Gruppe existiert nicht",
    "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
    "Operation #%s does not exist" : "Operation #%s existert nicht",
    "Operation %s does not exist" : "Operation %s existert nicht",
    "Operation %s is invalid" : "Operation %s ist ungültig",
    "Check %s does not exist" : "Die Prüfung %s existiert nicht",
    "Check %s is invalid" : "Die Prüfung %s ist ungültig",
    "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
    "Workflow" : "Workflow",
    "Open documentation" : "Dokumentation öffnen",
    "Add rule group" : "Regelgruppe hinzufügen",
    "Short rule description" : "Kurze Regelbeschreibung",
    "Add rule" : "Regel hinzufügen",
    "Reset" : "Zurücksetzen",
    "Save" : "Speichern",
    "Saving…" : "Speichern…",
    "Loading…" : "Laden…",
    "Successfully saved" : "Erfolgreich gespeichert",
    "File mime type" : "Datei MIME-Typ"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.10.tar.bz2: nextcloud/apps/workflowengine/l10n/de.js <==
OC.L10N.register(
    "workflowengine",
    {
    "File MIME type" : "Datei MIME-Typ",
    "is" : "ist",
    "is not" : "ist nicht",
    "matches" : "entspricht",
    "does not match" : "entspricht nicht",
    "Example: {placeholder}" : "Beispiel: {placeholder}",
    "File name" : "Dateiname",
    "File size (upload)" : "Dateigröße (beim Hochladen)",
    "less" : "weniger",
    "less or equals" : "weniger oder gleich",
    "greater or equals" : "größer oder gleich",
    "greater" : "größer",
    "File system tag" : "Dateisystem-Schlagwort",
    "is tagged with" : "hat das Schlagwort",
    "is not tagged with" : "ist nicht verschlagwortet mit",
    "Select tag…" : "Wähle ein Schlagwort…",
    "Request remote address" : "IP Adresse der Anfrage",
    "matches IPv4" : "entspricht IPv4",
    "does not match IPv4" : "entspricht nicht IPv4",
    "matches IPv6" : "entspricht IPv6",
    "does not match IPv6" : "entspricht nicht IPv6",
    "Request time" : "Anfrage-Zeitpunkt",
    "between" : "zwischen",
    "not between" : "nicht zwischen",
    "Start" : "Start",
    "End" : "Ende",
    "Select timezone…" : "Wähle eine Zeitzone…",
    "Request URL" : "Anfrage-URL",
    "Predefined URLs" : "Vordefinierte URLs",
    "Files WebDAV" : "WebDAV für Dateien",
    "Request user agent" : "User-Agent",
    "Sync clients" : "Sync-Clients",
    "Android client" : "Android-Client",
    "iOS client" : "iOS-Client",
    "Desktop client" : "Desktop-Client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "User group membership" : "Benutzergruppen-Mitgliedschaft",
    "is member of" : "ist Mitglied von",
    "is not member of" : "ist kein Mitglied von",
    "Short rule description" : "Kurze Regelbeschreibung",
    "Add rule" : "Regel hinzufügen",
    "Reset" : "Zurücksetzen",
    "Save" : "Speichern",
    "Saving…" : "Speichern…",
    "Group list is empty" : "Gruppenliste ist leer",
    "Unable to retrieve the group list" : "Gruppenliste konnte nicht empfangen werden",
    "Saved" : "Gespeichert",
    "Saving failed:" : "Speichern fehlgeschlagen:",
    "Add rule group" : "Regelgruppe hinzufügen",
    "The given operator is invalid" : "Der angegebene Operator ist ungültig",
    "The given regular expression is invalid" : "Der angegebene Reguläre Ausdruck ist ungültig",
    "The given file size is invalid" : "Die angegebene Dateigröße ist ungültig",
    "The given tag id is invalid" : "Die angegebene Schlagwort-ID ist ungültig",
    "The given IP range is invalid" : "Der angegebene IP-Bereich ist ungültig",
    "The given IP range is not valid for IPv4" : "Der angegebene IP-Bereich ist ungültig für IPv4",
    "The given IP range is not valid for IPv6" : "Der angegebene IP-Bereich ist ungültig für IPv6",
    "The given time span is invalid" : "Die angegebene Zeitspanne ist ungütlig",
    "The given start time is invalid" : "Die angegebene Anfangszeit ist ungültig",
    "The given end time is invalid" : "Die angegebene Endzeit ist ungültig",
    "The given group does not exist" : "Die angegebene Gruppe existiert nicht",
    "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
    "Operation #%s does not exist" : "Operation #%s existert nicht",
    "Operation %s does not exist" : "Operation %s existert nicht",
    "Operation %s is invalid" : "Operation %s ist ungültig",
    "Check %s does not exist" : "Die Prüfung %s existiert nicht",
    "Check %s is invalid" : "Die Prüfung %s ist ungültig",
    "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
    "Tag management" : "Schlagwortverwaltung",
    "Files workflow engine" : "Datei-Arbeitsablauf-Engine",
    "Open documentation" : "Dokumentation öffnen",
    "Loading…" : "Laden…",
    "Workflow" : "Arbeitsablauf"
},
"nplurals=2; plural=(n != 1);");
